@@ -21,6 +21,7 @@ from requests import get as http_get
 
 from opwen_email_server.config import MAX_HEIGHT_IMAGES
 from opwen_email_server.config import MAX_WIDTH_IMAGES
+from opwen_email_server.constants import mailbox
 from opwen_email_server.utils.log import LogMixin
 from opwen_email_server.utils.serialization import to_base64
 
@@ -225,6 +226,10 @@ def format_inline_images(email: dict, on_error: Callable) -> dict:
     return new_email
 
 
+def descending_timestamp(email_sent_at: str) -> str:
+    return str(mailbox.FUTURE_TIMESTAMP - int(datetime.fromisoformat(email_sent_at).timestamp()))
+
+
 class MimeEmailParser(LogMixin):
     def __call__(self, mime_email: str) -> dict:
         email = parse_mime_email(mime_email)
